==> difffilter-0.3.1.tar.bz2: difffilter-0.3.1/tests/cli.sh <==
#!/bin/sh
#
# Copyright (C) 2011 Nathan Phillip Brink <ohnobinki@ohnopublishing.net>
#
# This file is a part of difffilter.
#
# difffilter is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# difffilter is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with difffilter.  If not, see <http://www.gnu.org/licenses/>.

. "${srcdir}"/tests/sh-common.sh

# do_diff [...] <a> <b>
#
# Performs a diff, removing some of the date/time info of the diff so
# that we can call diff multiple times and get the same file.
do_diff() {
    diff "${@}" | sed -e 's/\(\(---\|+++\) [^ \t]\+[ \t]\).*$/\1/'
}

for prog in cmp diff grep sed; do
    check_program_available ${prog}
done

filesdir="${srcdir}/tests/files"
diffsdir="${srcdir}/tests/diffs"
testdir="tests/outfiles"

mkdir -p "${testdir}"

base_diff_file="${testdir}"/a_b_base.diff
do_diff -U 4 "${filesdir}"/a "${filesdir}"/b > "${base_diff_file}"

for lines_context in 0 1 2 3; do
    diff_file="${testdir}"/a_b_${lines_context}.diff
    difffilter_file="${testdir}"/a_b_${lines_context}.difffilter

    do_diff -U ${lines_context} "${filesdir}"/a "${filesdir}"/b > "${diff_file}"
    ./difffilter -U ${lines_context} < "${base_diff_file}" > "${difffilter_file}"

    if cmp "${diff_file}" "${difffilter_file}"; then
	rm "${diff_file}" "${difffilter_file}"
    else
	echo "Failed at -U ${lines_context}. \`${diff_file}' and \`${difffilter_file}' differ." >&2
	exit 1
    fi
done

# test -E versus -e
difffilter_file="${testdir}"/a_b_base.difffilter

# sanity check, destination "${difffilter_file}" should be empty after
# this match.
if ! ./difffilter -e '/a$' < "${base_diff_file}" > "${difffilter_file}" \
    || grep -q -e '/a' "${difffilter_file}"; then
    echo "Failed sanity test using -e: Expected output file \`${difffilter_file}' to be empty, but it wasn't." >&2
    exit 1
fi

# shouldn't match
if ! ./difffilter -e '/a?$' < "${base_diff_file}" > "${difffilter_file}" \
    || ! cmp "${base_diff_file}" "${difffilter_file}"; then
    echo "Failed verification that -e only supports BREs, \`${base_diff_file}' and \`${difffilter_file}' differ when they shouldn't." >&2
    exit 1
fi

# should match
if ! ./difffilter -E '/a?$' < "${base_diff_file}" > "${difffilter_file}" \
    || cmp "${base_diff_file}" "${difffilter_file}" >/dev/null; then
    echo "Failed verification that -E supports EREs, \`${base_diff_file}' and \`${difffilter_file}' do NOT differ when they should." >&2
    exit 1
fi

rm "${base_diff_file}" "${difffilter_file}"

# test -k
cvs_diff_file="${testdir}"/cvs_a_b.diff
cvs_difffilter_file="${testdir}"/cvs_a_b.difffilter

do_diff -u "${filesdir}"/cvs_a "${filesdir}"/cvs_b > "${cvs_diff_file}"

./difffilter < "${cvs_diff_file}" > "${cvs_difffilter_file}"
if ! cmp "${cvs_diff_file}" "${cvs_difffilter_file}"; then
    echo "Failed, difffilter modified file without being supposed to. \`${cvs_diff_file}' and \`${cvs_difffilter_file}' differ." >&2
    exit 1
fi

./difffilter -k '^Id$' < "${cvs_diff_file}" > "${cvs_difffilter_file}"
if cmp "${cvs_diff_file}" "${cvs_difffilter_file}" >/dev/null || grep -q -e '1\.1\.1\.1\.6\.1\.2\.50\.2\.13' "${cvs_difffilter_file}"; then
    echo "Failed, CVS keyword \$Id\$ was not removed from \`${cvs_diff_file}' (result in \`${cvs_difffilter_file}')." >&2
    exit 1
fi

./difffilter -k '^Id$' -U 3 < "${cvs_diff_file}" > "${cvs_difffilter_file}"
# we should have an empty output file, essentially.
if grep -q -e 'echo' "${cvs_difffilter_file}" || grep -q -e 'Id' "${cvs_difffilter_file}"; then
    echo "Failed, diff sections containing CVS keyword \$Id\$ were not nullified. Output in \`${cvs_difffilter_file}\'" >&2
    exit 1
fi

# test -K versus -k
# this should not filter anything
./difffilter -k 'Id?' < "${cvs_diff_file}" > "${cvs_difffilter_file}"
if ! cmp "${cvs_diff_file}" "${cvs_difffilter_file}"; then
    echo "Failed, BRE of 'Id?' should not match any of the CVS keywords in \`${cvs_diff_file}' but difffilter modified the diff (\`${cvs_difffilter_file}')." >&2
    exit 1
fi

# this should filter something
./difffilter -K 'Id?' < "${cvs_diff_file}" > "${cvs_difffilter_file}"
if cmp "${cvs_diff_file}" "${cvs_difffilter_file}" >/dev/null; then
    echo "Failed, ERE of 'Id?' should match our CVS keywords in \`${cvs_diff_file}', but difffilter did not modify the diff (\`${cvs_difffilter_file}')." >&2
    exit 1
fi

# done testing CVS keyword support
rm "${cvs_diff_file}" "${cvs_difffilter_file}"

# Test specific piece of CVS keyword support
# this should filter something
shortkeyword_diff_file="${diffsdir}/short-cvs-keyword.patch"
shortkeyword_difffilter_file="${testdir}"/short-cvs-keyword.patch
./difffilter -K . < "${shortkeyword_diff_file}" > "${shortkeyword_difffilter_file}"
if cmp "${shortkeyword_diff_file}" "${shortkeyword_difffilter_file}" >/dev/null; then
    echo "Failed to eliminate keywords which looks like \$Id:\$. Input: \`${shortkeyword_diff_file}', output: \`${shortkeyword_difffilter_file}'." >&2
    exit 1
fi
rm "${shortkeyword_difffilter_file}"

# Test proper multifile support.
multifile_diff_file="${diffsdir}"/multifile.patch
multifile_difffilter_file="${testdir}"/multifile.patch
if ! ./difffilter < "${multifile_diff_file}" > "${multifile_difffilter_file}" \
    || ! cmp "${multifile_diff_file}" "${multifile_difffilter_file}"; then
    echo "Failed to properly pass through a diff addressing multiple files." >&2
    exit 1
fi
rm "${multifile_difffilter_file}"

# test short-header support, where diffs only have the `+++
# <filename>' line instead of also having `---'. difffilter likes to
# add the `---' line itself (which is good IMO) but thus we need to
# filter that out with a grep.
shortheader_diff_file="${diffsdir}"/short-header.patch
shortheader_difffilter_file="${testdir}"/short-header.patch
if ! ./difffilter < "${shortheader_diff_file}" | grep -v -e '^---' > "${shortheader_difffilter_file}" \
    || ! cmp "${shortheader_diff_file}" "${shortheader_difffilter_file}"; then
    echo "Failed to support passing-through a diff file with short headers (having +++ lines but no --- lines)." >&2
    exit 1
fi

# Test that with short headers, normal difffilter functions work
# correctly.
shortheader_correct_difffilter_file="${diffsdir}"/short-header-no-Reflector.py.patch
if ! ./difffilter -e '^Reflector\.py$' < "${shortheader_diff_file}" > "${shortheader_difffilter_file}" \
    || ! cmp "${shortheader_difffilter_file}" "${shortheader_correct_difffilter_file}"; then
    echo "Normal difffilter functionality failed for diff file with short headers. -incorrect +correct shown below:" >&2
    diff -u "${shortheader_difffilter_file}" "${shortheader_correct_difffilter_file}" >&2
    exit 1
fi
rm "${shortheader_difffilter_file}"

exit 0

==> difffilter-0.3.3.tar.bz2: difffilter-0.3.3/tests/cli.sh <==
#!/bin/sh
#
# Copyright (C) 2011 Nathan Phillip Brink <ohnobinki@ohnopublishing.net>
#
# This file is a part of difffilter.
#
# difffilter is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# difffilter is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with difffilter.  If not, see <http://www.gnu.org/licenses/>.

. "${srcdir}"/tests/sh-common.sh

# do_diff [...] <a> <b>
#
# Performs a diff, removing some of the date/time info of the diff so
# that we can call diff multiple times and get the same file.
do_diff() {
    diff "${@}" | sed -e 's/\(\(---\|+++\) [^ \t]\+[ \t]\).*$/\1/'
}

for prog in cmp diff grep sed; do
    check_program_available ${prog}
done

filesdir="${srcdir}/tests/files"
diffsdir="${srcdir}/tests/diffs"
testdir="tests/outfiles"

mkdir -p "${testdir}"

base_diff_file="${testdir}"/a_b_base.diff
do_diff -U 4 "${filesdir}"/a "${filesdir}"/b > "${base_diff_file}"

for lines_context in 0 1 2 3; do
    diff_file="${testdir}"/a_b_${lines_context}.diff
    difffilter_file="${testdir}"/a_b_${lines_context}.difffilter

    do_diff -U ${lines_context} "${filesdir}"/a "${filesdir}"/b > "${diff_file}"
    ./difffilter${EXEEXT} -U ${lines_context} < "${base_diff_file}" > "${difffilter_file}"

    if cmp "${diff_file}" "${difffilter_file}"; then
	rm "${diff_file}" "${difffilter_file}"
    else
	echo "Failed at -U ${lines_context}. \`${diff_file}' and \`${difffilter_file}' differ." >&2
	exit 1
    fi
done

# test -E versus -e
difffilter_file="${testdir}"/a_b_base.difffilter

# sanity check, destination "${difffilter_file}" should be empty after
# this match.
if ! ./difffilter${EXEEXT} -e '/a$' < "${base_diff_file}" > "${difffilter_file}" \
    || grep -q -e '/a' "${difffilter_file}"; then
    echo "Failed sanity test using -e: Expected output file \`${difffilter_file}' to be empty, but it wasn't." >&2
    exit 1
fi

# shouldn't match
if ! ./difffilter${EXEEXT} -e '/a?$' < "${base_diff_file}" > "${difffilter_file}" \
    || ! cmp "${base_diff_file}" "${difffilter_file}"; then
    echo "Failed verification that -e only supports BREs, \`${base_diff_file}' and \`${difffilter_file}' differ when they shouldn't." >&2
    exit 1
fi

# should match
if ! ./difffilter${EXEEXT} -E '/a?$' < "${base_diff_file}" > "${difffilter_file}" \
    || cmp "${base_diff_file}" "${difffilter_file}" >/dev/null; then
    echo "Failed verification that -E supports EREs, \`${base_diff_file}' and \`${difffilter_file}' do NOT differ when they should." >&2
    exit 1
fi

rm "${base_diff_file}" "${difffilter_file}"

# test -k
cvs_diff_file="${testdir}"/cvs_a_b.diff
cvs_difffilter_file="${testdir}"/cvs_a_b.difffilter

do_diff -u "${filesdir}"/cvs_a "${filesdir}"/cvs_b > "${cvs_diff_file}"

./difffilter${EXEEXT} < "${cvs_diff_file}" > "${cvs_difffilter_file}"
if ! cmp "${cvs_diff_file}" "${cvs_difffilter_file}"; then
    echo "Failed, difffilter modified file without being supposed to. \`${cvs_diff_file}' and \`${cvs_difffilter_file}' differ." >&2
    exit 1
fi

./difffilter${EXEEXT} -k '^Id$' < "${cvs_diff_file}" > "${cvs_difffilter_file}"
if cmp "${cvs_diff_file}" "${cvs_difffilter_file}" >/dev/null || grep -q -e '1\.1\.1\.1\.6\.1\.2\.50\.2\.13' "${cvs_difffilter_file}"; then
    echo "Failed, CVS keyword \$Id\$ was not removed from \`${cvs_diff_file}' (result in \`${cvs_difffilter_file}')." >&2
    exit 1
fi

./difffilter${EXEEXT} -k '^Id$' -U 3 < "${cvs_diff_file}" > "${cvs_difffilter_file}"
# we should have an empty output file, essentially.
if grep -q -e 'echo' "${cvs_difffilter_file}" || grep -q -e 'Id' "${cvs_difffilter_file}"; then
    echo "Failed, diff sections containing CVS keyword \$Id\$ were not nullified. Output in \`${cvs_difffilter_file}\'" >&2
    exit 1
fi

# test -K versus -k
# this should not filter anything
./difffilter${EXEEXT} -k 'Id?' < "${cvs_diff_file}" > "${cvs_difffilter_file}"
if ! cmp "${cvs_diff_file}" "${cvs_difffilter_file}"; then
    echo "Failed, BRE of 'Id?' should not match any of the CVS keywords in \`${cvs_diff_file}' but difffilter modified the diff (\`${cvs_difffilter_file}')." >&2
    exit 1
fi

# this should filter something
./difffilter${EXEEXT} -K 'Id?' < "${cvs_diff_file}" > "${cvs_difffilter_file}"
if cmp "${cvs_diff_file}" "${cvs_difffilter_file}" >/dev/null; then
    echo "Failed, ERE of 'Id?' should match our CVS keywords in \`${cvs_diff_file}', but difffilter did not modify the diff (\`${cvs_difffilter_file}')." >&2
    exit 1
fi

# done testing CVS keyword support
rm "${cvs_diff_file}" "${cvs_difffilter_file}"

# Test specific piece of CVS keyword support
# this should filter something
shortkeyword_diff_file="${diffsdir}/short-cvs-keyword.patch"
shortkeyword_difffilter_file="${testdir}"/short-cvs-keyword.patch
./difffilter${EXEEXT} -K . < "${shortkeyword_diff_file}" > "${shortkeyword_difffilter_file}"
if cmp "${shortkeyword_diff_file}" "${shortkeyword_difffilter_file}" >/dev/null; then
    echo "Failed to eliminate keywords which looks like \$Id:\$. Input: \`${shortkeyword_diff_file}', output: \`${shortkeyword_difffilter_file}'." >&2
    exit 1
fi
rm "${shortkeyword_difffilter_file}"

# Test proper multifile support.
multifile_diff_file="${diffsdir}"/multifile.patch
multifile_difffilter_file="${testdir}"/multifile.patch
if ! ./difffilter${EXEEXT} < "${multifile_diff_file}" > "${multifile_difffilter_file}" \
    || ! cmp "${multifile_diff_file}" "${multifile_difffilter_file}"; then
    echo "Failed to properly pass through a diff addressing multiple files." >&2
    exit 1
fi
rm "${multifile_difffilter_file}"

# test short-header support, where diffs only have the `+++
# <filename>' line instead of also having `---'. difffilter likes to
# add the `---' line itself (which is good IMO) but thus we need to
# filter that out with a grep.
shortheader_diff_file="${diffsdir}"/short-header.patch
shortheader_difffilter_file="${testdir}"/short-header.patch
if ! ./difffilter${EXEEXT} < "${shortheader_diff_file}" | grep -v -e '^---' > "${shortheader_difffilter_file}" \
    || ! cmp "${shortheader_diff_file}" "${shortheader_difffilter_file}"; then
    echo "Failed to support passing-through a diff file with short headers (having +++ lines but no --- lines)." >&2
    exit 1
fi

# Test that with short headers, normal difffilter functions work
# correctly.
shortheader_correct_difffilter_file="${diffsdir}"/short-header-no-Reflector.py.patch
if ! ./difffilter${EXEEXT} -e '^Reflector\.py$' < "${shortheader_diff_file}" > "${shortheader_difffilter_file}" \
    || ! cmp "${shortheader_difffilter_file}" "${shortheader_correct_difffilter_file}"; then
    echo "Normal difffilter functionality failed for diff file with short headers. -incorrect +correct shown below:" >&2
    diff -u "${shortheader_difffilter_file}" "${shortheader_correct_difffilter_file}" >&2
    exit 1
fi
rm "${shortheader_difffilter_file}"

exit 0
